==> spip_3.2.9.orig.tar.xz: plugins-dist/medias/lang/medias_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Аудио файлов нет',
	'aucun_document' => 'Нет документов (файлов)',
	'aucun_file' => 'Нет документов (файлов)',
	'aucun_image' => 'Нет файлов изображений',
	'aucun_video' => 'Видео файлов нет',
	'aucune_utilisation' => 'Документ не используется.',
	'aucune_vignette' => 'Нет миниатюры',

	// B
	'bouton_ajouter_document' => 'Добавить документ',
	'bouton_ajouter_image' => 'Добавить изображение',
	'bouton_ajouter_image_document' => 'Добавить изображение или документ',
	'bouton_attacher_document' => 'Добавить',
	'bouton_copier_local' => 'Добавить на сайт',
	'bouton_download_depuis' => 'добавить файлы:',
	'bouton_download_local' => 'с моего компьютера',
	'bouton_download_par_ftp' => 'с сервера',
	'bouton_download_par_mediatheque' => 'из добавленных',
	'bouton_download_sur_le_web' => 'из интернета',
	'bouton_enlever_document' => 'Убрать',
	'bouton_enlever_supprimer_document' => 'Удалить',
	'bouton_enlever_supprimer_document_confirmation' => 'Вы уверенны, что хотите удалить документ (файл)?',
	'bouton_modifier_document' => 'Изменить',
	'bouton_parcourir' => 'Обзор...',
	'bouton_refresh_document' => 'Обновить документ',
	'bouton_remplacer_document' => 'Заменить документ',
	'bouton_remplacer_image' => 'Заменить изображение',
	'bouton_remplacer_image_document' => 'Заменить изображением или файлом',
	'bouton_supprimer' => 'Удалить',
	'bouton_supprimer_tous_orphelins' => 'Удалить неиспользуемые',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Вы действительно хотите удалить @nb@ документов (файлов) ?',
	'bouton_upload' => 'Добавить',

	// D
	'des_audios' => '@nb@ аудио файлов',
	'des_documents' => '@nb@ документов (файлов)',
	'des_files' => '@nb@ документов (файлов)',
	'des_images' => '@nb@ файлов изображений',
	'des_utilisations' => 'Используется @nb@ раз(а)',
	'des_videos' => '@nb@ видео файлов',
	'descriptif' => 'Описание',
	'document_attache_succes' => 'Документ (файл) добавлен успешно',
	'document_copie_locale_succes' => 'Файл успешно скопирован на сайт',
	'document_installe_succes' => 'Файл добавлен успешно',
	'document_vu' => 'В тексте',
	'documents' => 'Управление файлами',
	'documents_brises' => 'Поврежденные',
	'documents_distants' => 'На других сайтах',
	'documents_locaux' => 'На нашем сайте',
	'documents_non_publies' => 'Не опубликованные',
	'documents_orphelins' => 'Не используемые',
	'documents_publies' => 'На сайте',
	'documents_tous' => 'Все',
	'double_clic_inserer_doc' => 'Дважды щелкните, чтобы вставить этот ярлык в текст',

	// E
	'entree_dimensions' => 'Размер:',
	'entree_titre_document' => 'Название документа:',
	'entree_titre_image' => 'Название изображения:',
	'erreur_aucun_document' => 'Этого документа нет в модуле управления файлами',
	'erreur_aucun_fichier' => 'Файл не найден',
	'erreur_chemin_distant' => 'Файл @nom@ с другого сайт не найден',
	'erreur_chemin_ftp' => 'Не удалось найти указанный файл на сервере',
	'erreur_copie_fichier' => 'Невозможно скопировать файл @nom@ в указанную папку',
	'erreur_dossier_tmp_manquant' => 'Не удается создать временную папку для загрузки файлов',
	'erreur_ecriture_fichier' => 'Ошибка при попытке записать на диск',
	'erreur_format_fichier_image' => 'Формат файла @nom@ не похож на формат изображения',
	'erreur_indiquez_un_fichier' => 'Укажите файл!',
	'erreur_insertion_document_base' => 'Не получается добавить документ @fichier@ в базу данных',
	'erreur_suppression_vignette' => 'При удалении миниатюры произошла ошибка',
	'erreur_upload_type_interdit' => 'Запрещена загрузка этого типа файла - @nom@',
	'erreur_upload_vignette' => 'При загрузке миниатюры возникла ошибка @nom@',
	'erreurs' => '@nb@ ошибок',
	'erreurs_voir' => 'Посмотреть ошибки (@nb@) ',

	// F
	'fichier_distant' => 'Файл на другом сайте',
	'fichier_manquant' => 'Файл не найден',
	'fichier_modifie' => 'Файл был изменен. Нажмите кнопку Сохранить.',
	'format_date_incorrect' => 'Неправильная дата или время',

	// I
	'icone_creer_document' => 'Добавить документ (файл)',
	'id' => 'ID',
	'image_tourner_180' => 'Повернуть на 180°',
	'image_tourner_droite' => 'Повернуть на 90° вправо',
	'image_tourner_gauche' => 'Поворот на 90° влево',
	'info_doc_max_poids' => 'Размер файла должен быть не больше @maxi@ (текущий размер @actuel@).',
	'info_document' => 'Документ',
	'info_document_indisponible' => 'Этот документ недоступен',
	'info_documents' => 'Файлы',
	'info_gauche_numero_document' => 'НОМЕР ДОКУМЕНТА',
	'info_hauteur' => 'Высота',
	'info_heure' => 'Время',
	'info_illustrations' => 'Фотографии в материале',
	'info_image_max_poids' => 'Размер файла изображения должен быть меньше @maxi@ (сейчас @actuel@).',
	'info_image_max_taille' => 'Размер файла изображения должен быть меньше @maxi@ (сейчас @actuel@).',
	'info_inclusion_directe' => 'Прямое включение:',
	'info_inclusion_vignette' => 'Добавить миниатюру:',
	'info_installer_tous_documents' => 'Добавить все файлы (документы)',
	'info_largeur' => 'Ширина',
	'info_logo_max_taille' => 'Логотипы должны быть меньше, чем @maxi@ (размер этого файла @actuel@).',
	'info_mode' => 'Режим (Mode)',
	'info_modifier_document' => 'Изменить файл',
	'info_portfolio' => 'Галерея фотографий и документов',
	'info_referencer_doc_distant' => 'Ссылка на файл (URL):',
	'info_sans_vignette' => 'Нет миниатюры',
	'info_statut_document' => 'Статус документа:',
	'info_taille' => 'Вес',
	'info_telecharger' => 'Загрузить с вашего компьютера:',
	'infos' => 'Техническая информация',
	'item_autoriser_selectionner_date_en_ligne' => 'Разрешить изменять дату добавления документа',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Запретить изменять дату добавления документа',

	// L
	'label_activer_document_objets' => 'Включить галерею:',
	'label_apercu' => 'Пред. просмотр',
	'label_caracteristiques' => 'Характеристики',
	'label_credits' => 'Информация о авторе',
	'label_fichier' => 'Файл',
	'label_fichier_vignette' => 'Миниатюра',
	'label_paginer_par' => 'Постранично по:',
	'label_parents' => 'Документ используется в:',
	'label_refdoc_joindre' => 'Номер документа',
	'lien_tout_enlever' => 'Удалить все',
	'logo' => 'Лого',

	// M
	'media_audio' => 'Аудио',
	'media_file' => 'Прочее',
	'media_image' => 'Изображения',
	'media_video' => 'Видео',
	'miniature_automatique_active' => 'SPIP создаст миниатюру автоматически',

	// N
	'nb_documents_attache_succes' => 'Добавлено @nb@ документов (файлов)',
	'nb_documents_installe_succes' => 'Успешно добавлено @nb@ файлов',

	// O
	'objet_document' => 'Документ',
	'objet_documents' => 'Документы',

	// P
	'par_date' => 'Дата',
	'par_hauteur' => 'Высота',
	'par_id' => 'ID',
	'par_largeur' => 'Ширина',
	'par_taille' => 'Размер',
	'par_titre' => 'Название',

	// T
	'texte_documents_joints' => 'Вы можете включить возможность добавлять файлы и документы (аудио, видео, офисные файлы) ко всем материалам сайта.',
	'texte_documents_joints_2' => 'Укажите, к каким материалам можно добавлять документы.',
	'titre_documents_joints' => 'Добавление документов (файлов) к материалам',
	'titre_page_documents_edit' => 'Изменить документ: @titre@',
	'tous_les_medias' => 'Все медиа файлы',
	'tout_dossier_upload' => 'Весь @upload@ каталог',
	'tout_voir' => 'Показать все',

	// U
	'un_audio' => '1 аудио файл',
	'un_document' => '1 документ (файл)',
	'un_file' => '1 документ (файл)',
	'un_image' => '1 изображение',
	'un_video' => '1 видео',
	'une_utilisation' => 'Используется 1 раз',
	'upload_fichier_zip' => 'ZIP файл',
	'upload_fichier_zip_texte' => 'Вы хотите добавить файл с архивом (zip).',
	'upload_fichier_zip_texte2' => 'Этот файл может быть:',
	'upload_info_mode_document' => 'Добавить в галерею',
	'upload_info_mode_image' => 'Убрать из галереи',
	'upload_limit' => 'Этот файл является слишком большим для сервера; максимально допустимый размер @max@.',
	'upload_zip_conserver' => 'Не удалять архив после извлечения файлов',
	'upload_zip_decompacter' => 'разархивировать и установить содержание каждого файла на сайт. Будут установлены файлы:',
	'upload_zip_mode_document' => 'Добавить все изображения в галерею',
	'upload_zip_telquel' => 'не разархивировать, добавить как ZIP файл;',
	'upload_zip_titrer' => 'Создать названия в соответствии с именами файлов',

	// V
	'verifier_documents_brises' => 'Проверить недостающие файлы',
	'verifier_documents_inutilises' => 'Проверить использование документа',
	'vignette_supprimee' => 'Миниатюра удалена'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Аудио файлов нет',
	'aucun_document' => 'Нет документов (файлов)',
	'aucun_file' => 'Нет документов (файлов)',
	'aucun_image' => 'Нет файлов изображений',
	'aucun_video' => 'Видео файлов нет',
	'aucune_utilisation' => 'Документ не используется.',
	'aucune_vignette' => 'Нет миниатюры',

	// B
	'bouton_ajouter_document' => 'Добавить документ',
	'bouton_ajouter_image' => 'Добавить изображение',
	'bouton_ajouter_image_document' => 'Добавить изображение или документ',
	'bouton_attacher_document' => 'Добавить',
	'bouton_copier_local' => 'Добавить на сайт',
	'bouton_download_depuis' => 'добавить файлы:',
	'bouton_download_local' => 'с моего компьютера',
	'bouton_download_par_ftp' => 'с сервера',
	'bouton_download_par_mediatheque' => 'из добавленных',
	'bouton_download_sur_le_web' => 'из интернета',
	'bouton_enlever_document' => 'Убрать',
	'bouton_enlever_supprimer_document' => 'Удалить',
	'bouton_enlever_supprimer_document_confirmation' => 'Вы уверенны, что хотите удалить документ (файл)?',
	'bouton_modifier_document' => 'Изменить',
	'bouton_parcourir' => 'Обзор...',
	'bouton_refresh_document' => 'Обновить документ',
	'bouton_remplacer_document' => 'Заменить документ',
	'bouton_remplacer_image' => 'Заменить изображение',
	'bouton_remplacer_image_document' => 'Заменить изображением или файлом',
	'bouton_supprimer' => 'Удалить',
	'bouton_supprimer_tous_orphelins' => 'Удалить неиспользуемые', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Вы действительно хотите удалить @nb@ документов (файлов) ?', # MODIF
	'bouton_upload' => 'Добавить',

	// D
	'des_audios' => '@nb@ аудио файлов',
	'des_documents' => '@nb@ документов (файлов)',
	'des_files' => '@nb@ документов (файлов)',
	'des_images' => '@nb@ файлов изображений',
	'des_utilisations' => 'Используется @nb@ раз(а)',
	'des_videos' => '@nb@ видео файлов',
	'descriptif' => 'Описание',
	'document_attache_succes' => 'Документ (файл) добавлен успешно',
	'document_copie_locale_succes' => 'Файл успешно скопирован на сайт',
	'document_installe_succes' => 'Файл добавлен успешно',
	'document_vu' => 'В тексте',
	'documents' => 'Управление файлами',
	'documents_brises' => 'Поврежденные',
	'documents_distants' => 'На других сайтах',
	'documents_locaux' => 'На нашем сайте',
	'documents_non_publies' => 'Не опубликованные',
	'documents_orphelins' => 'Не используемые',
	'documents_publies' => 'На сайте',
	'documents_tous' => 'Все',
	'double_clic_inserer_doc' => 'Дважды щелкните, чтобы вставить этот ярлык в текст',

	// E
	'entree_dimensions' => 'Размер:',
	'entree_titre_document' => 'Название документа:',
	'entree_titre_image' => 'Название изображения:',
	'erreur_aucun_document' => 'Этого документа нет в модуле управления файлами',
	'erreur_aucun_fichier' => 'Файл не найден',
	'erreur_chemin_distant' => 'Файл @nom@ с другого сайт не найден',
	'erreur_chemin_ftp' => 'Не удалось найти указанный файл на сервере',
	'erreur_copie_fichier' => 'Невозможно скопировать файл @nom@ в указанную папку',
	'erreur_dossier_tmp_manquant' => 'Не удается создать временную папку для загрузки файлов',
	'erreur_ecriture_fichier' => 'Ошибка при попытке записать на диск',
	'erreur_format_fichier_image' => 'Формат файла @nom@ не похож на формат изображения',
	'erreur_indiquez_un_fichier' => 'Укажите файл!',
	'erreur_insertion_document_base' => 'Не получается добавить документ @fichier@ в базу данных',
	'erreur_suppression_vignette' => 'При удалении миниатюры произошла ошибка',
	'erreur_upload_type_interdit' => 'Запрещена загрузка этого типа файла - @nom@',
	'erreur_upload_vignette' => 'При загрузке миниатюры возникла ошибка @nom@',
	'erreurs' => '@nb@ ошибок',
	'erreurs_voir' => 'Посмотреть ошибки (@nb@) ',

	// F
	'fichier_distant' => 'Файл на другом сайте',
	'fichier_manquant' => 'Файл не найден',
	'fichier_modifie' => 'Файл был изменен. Нажмите кнопку Сохранить.',
	'format_date_incorrect' => 'Неправильная дата или время',

	// I
	'icone_creer_document' => 'Добавить документ (файл)',
	'id' => 'ID',
	'image_tourner_180' => 'Повернуть на 180°',
	'image_tourner_droite' => 'Повернуть на 90° вправо',
	'image_tourner_gauche' => 'Поворот на 90° влево',
	'info_doc_max_poids' => 'Размер файла должен быть не больше @maxi@ (текущий размер @actuel@).',
	'info_document' => 'Документ',
	'info_document_indisponible' => 'Этот документ недоступен',
	'info_documents' => 'Файлы',
	'info_gauche_numero_document' => 'НОМЕР ДОКУМЕНТА',
	'info_hauteur' => 'Высота',
	'info_heure' => 'Время',
	'info_illustrations' => 'Фотографии в материале',
	'info_image_max_poids' => 'Размер файла изображения должен быть меньше @maxi@ (сейчас @actuel@).',
	'info_image_max_taille' => 'Размер файла изображения должен быть меньше @maxi@ (сейчас @actuel@).',
	'info_inclusion_directe' => 'Прямое включение:',
	'info_inclusion_vignette' => 'Добавить миниатюру:',
	'info_installer_tous_documents' => 'Добавить все файлы (документы)',
	'info_largeur' => 'Ширина',
	'info_logo_max_taille' => 'Логотипы должны быть меньше, чем @maxi@ (размер этого файла @actuel@).',
	'info_mode' => 'Режим (Mode)',
	'info_modifier_document' => 'Изменить файл',
	'info_portfolio' => 'Галерея фотографий и документов',
	'info_referencer_doc_distant' => 'Ссылка на файл (URL):',
	'info_sans_vignette' => 'Нет миниатюры',
	'info_statut_document' => 'Статус документа:',
	'info_taille' => 'Вес',
	'info_telecharger' => 'Загрузить с вашего компьютера:',
	'infos' => 'Техническая информация',
	'item_autoriser_selectionner_date_en_ligne' => 'Разрешить изменять дату добавления документа',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Запретить изменять дату добавления документа',

	// L
	'label_activer_document_objets' => 'Включить галерею:',
	'label_apercu' => 'Пред. просмотр',
	'label_caracteristiques' => 'Характеристики',
	'label_credits' => 'Информация о авторе',
	'label_fichier' => 'Файл',
	'label_fichier_vignette' => 'Миниатюра',
	'label_paginer_par' => 'Постранично по:',
	'label_parents' => 'Документ используется в:',
	'label_refdoc_joindre' => 'Номер документа',
	'lien_tout_enlever' => 'Удалить все', # MODIF
	'logo' => 'Лого',

	// M
	'media_audio' => 'Аудио',
	'media_file' => 'Прочее',
	'media_image' => 'Изображения',
	'media_video' => 'Видео',
	'miniature_automatique_active' => 'SPIP создаст миниатюру автоматически',

	// N
	'nb_documents_attache_succes' => 'Добавлено @nb@ документов (файлов)',
	'nb_documents_installe_succes' => 'Успешно добавлено @nb@ файлов',

	// O
	'objet_document' => 'Документ',
	'objet_documents' => 'Документы',

	// P
	'par_date' => 'Дата',
	'par_hauteur' => 'Высота',
	'par_id' => 'ID',
	'par_largeur' => 'Ширина',
	'par_taille' => 'Размер',
	'par_titre' => 'Название',

	// T
	'texte_documents_joints' => 'Вы можете включить возможность добавлять файлы и документы (аудио, видео, офисные файлы) ко всем материалам сайта.',
	'texte_documents_joints_2' => 'Укажите, к каким материалам можно добавлять документы.',
	'titre_documents_joints' => 'Добавление документов (файлов) к материалам',
	'titre_page_documents_edit' => 'Изменить документ: @titre@',
	'tous_les_medias' => 'Все медиа файлы',
	'tout_dossier_upload' => 'Весь @upload@ каталог',
	'tout_voir' => 'Показать все',

	// U
	'un_audio' => '1 аудио файл',
	'un_document' => '1 документ (файл)',
	'un_file' => '1 документ (файл)',
	'un_image' => '1 изображение',
	'un_video' => '1 видео',
	'une_utilisation' => 'Используется 1 раз',
	'upload_fichier_zip' => 'ZIP файл',
	'upload_fichier_zip_texte' => 'Вы хотите добавить файл с архивом (zip).',
	'upload_fichier_zip_texte2' => 'Этот файл может быть:',
	'upload_info_mode_document' => 'Добавить в галерею',
	'upload_info_mode_image' => 'Убрать из галереи',
	'upload_limit' => 'Этот файл является слишком большим для сервера; максимально допустимый размер @max@.',
	'upload_zip_conserver' => 'Не удалять архив после извлечения файлов',
	'upload_zip_decompacter' => 'разархивировать и установить содержание каждого файла на сайт. Будут установлены файлы:',
	'upload_zip_mode_document' => 'Добавить все изображения в галерею',
	'upload_zip_telquel' => 'не разархивировать, добавить как ZIP файл;',
	'upload_zip_titrer' => 'Создать названия в соответствии с именами файлов',

	// V
	'verifier_documents_brises' => 'Проверить недостающие файлы',
	'verifier_documents_inutilises' => 'Проверить использование документа',
	'vignette_supprimee' => 'Миниатюра удалена'
);
